@@ -1,7 +1,25 @@
-from base import QuickbooksBaseObject, Ref
+from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject
 
 
-class Budget(QuickbooksBaseObject):
+class BudgetDetail(QuickbooksBaseObject):
+    class_dict = {
+        "AccountRef": Ref,
+        "CustomerRef": Ref
+    }
+
+    def __init__(self):
+        super(BudgetDetail, self).__init__()
+        self.BudgetDate = ""
+        self.Amount = 0
+
+        self.AccountRef = None
+        self.CustomerRef = None
+
+    def __unicode__(self):
+        return self.Amount
+
+
+class Budget(QuickbooksManagedObject):
     """
     QBO definition: The Budget endpoint allows you to retrieve the current state of budgets already set up in the user's
     company file. A budget allows for an amount to be assigned on a monthly, quarterly, or annual basis for a specific
@@ -16,6 +34,7 @@ class Budget(QuickbooksBaseObject):
     qbo_object_name = "Budget"
 
     def __init__(self):
+        super(Budget, self).__init__()
         self.Name = ""
         self.StartDate = ""
         self.EndDate = ""
@@ -28,19 +47,3 @@ class Budget(QuickbooksBaseObject):
     def __unicode__(self):
         return self.Name
 
-
-class BudgetDetail(QuickbooksBaseObject):
-    class_dict = {
-        "AccountRef": Ref,
-        "CustomerRef": Ref
-    }
-
-    def __init__(self):
-        self.BudgetDate = ""
-        self.Amount = 0
-
-        self.AccountRef = None
-        self.CustomerRef = None
-
-    def __unicode__(self):
-        return self.Amount
\ No newline at end of file
